%global __provides_exclude perl\\(.*\\)
%global __requires_exclude perl\\((Sympa.*|Archive|Auth|Bounce|Bulk|Commands|Conf|Config_XML|Datasource|Family|Fetch|Language|Ldap|List|Lock|Log|Marc.*|Message|PlainDigest|Robot|SDM|SharedDocument|Scenario|SQLSource|Task|Upgrade|WebAgent|admin|confdef|mail|report|tools|tt2|wwslib)\\)
%global __requires_exclude %{?__requires_exclude}|^perl\\((cookielib|sympasoap|time_utils)\\)

Name:		sympa
Version:	6.2.74
Release:	%mkrel 1
Summary:	Electronic mailing list manager
License:	GPL
Group:		System/Servers
URL:		https://www.sympa.community/
Source0:	https://github.com/sympa-community/sympa/releases/download/%{version}/sympa-%{version}.tar.gz
Source1:	README.update.urpmi
Source6:	sympa.tmpfiles
Requires:	openssl >= 0.9.5a
Requires:	mhonarc >= 2.4.5
Requires:   mail-server
Requires:   sympa-database
Recommends: perl-Mail-DKIM
Requires(pre):	    rpm-helper
Requires(post):     rpm-helper >= 0.20.0
Requires(post):     mail-server
Requires(preun):    rpm-helper
Requires(preun):    mail-server
Requires(postun):   rpm-helper >= 0.16
BuildRequires:      rpm-helper >= 0.20.0
BuildRequires:      rpm-mageia-setup
BuildRequires:	    pkgconfig(openssl)
BuildRequires:	    perl-Class-Singleton
BuildRequires:	    perl-DateTime
BuildRequires:	    perl-DBI
BuildRequires:	    perl-File-Copy-Recursive
BuildRequires:	    perl-HTML-Parser
BuildRequires:	    perl-MailTools
BuildRequires:	    perl-MIME-EncWords
BuildRequires:	    perl-Unicode-LineBreak
BuildRequires:	    perl-Unicode-UTF8
BuildRequires:	    perl-URI
BuildRequires:	    perl-libintl-perl
BuildRequires:	    gettext-devel

%description
Sympa is an open source mailing list manager. It provides advanced features with a rich and secure web interface.

%package www
Summary:	Web interface for Sympa
Group:		System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	webserver
Recommends:   apache-mod_fastcgi
Recommends:   perl(CGI::Fast)
Recommends:   perl(FCGI)
Requires(post):     rpm-helper >= 0.20.0
Requires(postun):   rpm-helper >= 0.16

%description www
This package contains the web interface for %{name}.

%package mysql
Summary:    MySQL database support for Sympa
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
Requires:   perl-DBD-mysql

%description mysql
This package ensures the necessary dependencies are in place for Sympa to
work with MySQL / MariaDB databases. It does not require a MySQL / MariaDB
server to be installed, as you may well wish to use a remote database
server.

%package postgresql
Summary:    PostgreSQL database support for Sympa
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
Requires:   perl-DBD-Pg

%description postgresql
This package ensures the necessary dependencies are in place for Sympa to
work with a PostgreSQL database. It does not require the PostgreSQL server
package to be installed, as you may well wish to use a remote database
server.

%prep
%autosetup -p1

%build
%serverbuild
autoreconf -i
%configure \
    --enable-fhs \
    --libexecdir=%{_sbindir} \
    --sysconfdir=%{_sysconfdir}/sympa \
    --with-unitsdir=%{_unitdir} \
    --with-confdir=%{_sysconfdir}/sympa \
    --with-aliases_file=%{_localstatedir}/lib/sympa/aliases \
    --with-newaliases_arg=-oA/var/lib/sympa/aliases
%make_build

%install
%make_install HOST=localhost

rm -f %{buildroot}%{_sysconfdir}/sympa/data_structure.version

perl -pi -e 's|/var/run|/run|' \
    %{buildroot}%{_sysconfdir}/sympa/sympa.conf \
    %{buildroot}%{_unitdir}/*.service

rm -f %{buildroot}%{_sysconfdir}/sympa/rc.d/init.d/sympa
install -D -m 644 %{SOURCE6} %{buildroot}%{_prefix}/lib/tmpfiles.d/sympa.conf

install -d -m 755 %{buildroot}%{_unitdir}/sympa.service.d

cat > %{buildroot}%{_unitdir}/sympa.service.d/mysql.conf <<EOF
[Unit]
After=mysqld.service
EOF

cat > %{buildroot}%{_unitdir}/sympa.service.d/postgresql.conf <<EOF
[Unit]
After=postgresql.service
EOF

# apache conf
install -d -m 755 %{buildroot}%{_webappconfdir}
cat > %{buildroot}%{_webappconfdir}/sympa.conf <<EOF
Alias /static-sympa %{_localstatedir}/lib/sympa/static_content
Alias /sympa %{_libdir}/sympa/cgi

<Directory %{_localstatedir}/lib/sympa/static_content>
    Require all granted
</Directory>

<Directory %{_libdir}/sympa/cgi>
    Options ExecCGI
    # fallback handler if mod_fcgid is not installed
    <IfModule !mod_fcgid.c>
        AddHandler cgi-script .fcgi
    </IfModule>
    DirectoryIndex wwsympa-wrapper.fcgi
    Require all granted
</Directory>
EOF

# no need for perl modules man pages
rm -rf %{buildroot}%{_mandir}/man3

# Install remaining documentation manually
install -m 644 AUTHORS.md COPYING NEWS.md README.md %{buildroot}%{_docdir}/%{name}
install -D -m 644 %{SOURCE1} README.update.urpmi

# don't install  bundled certs
rm -f %{buildroot}%{_datadir}/sympa/ca-bundle.crt

# not the place for documentation
rm -f %{buildroot}%{_sysconfdir}/sympa/README

# drop sendmail stuff
rm -rf %{buildroot}%{_sysconfdir}/sympa/smrsh

%find_lang sympa
%find_lang web_help
cat web_help.lang >> sympa.lang

%pre
%_pre_useradd sympa %{_localstatedir}/lib/sympa /bin/false

%post
%_post_service sympa

if [ $1 = 1 ]; then
  # installation

  # sympa configuration
  hostname=`hostname`

  perl -pi \
    -e "s|^domain(\s+).*|domain\$1$hostname|;" \
    -e "s|^listmaster(\s+).*|listmaster\$1listmaster\@$hostname|;" \
    -e "s|^wwsympa_url(\s+).*|wwsympa_url\$1http://$hostname/sympa|;" \
    -e "s|^syslog(\s+).*|syslog\$1mail|;" \
    %{_sysconfdir}/sympa/sympa.conf

  # Initial aliase file creation
  cat >> %{_localstatedir}/lib/sympa/aliases <<EOF
listmaster:	"|%{_sbindir}/queue listmaster"
sympa:		"|%{_sbindir}/queue sympa"
bounce+*:	"|%{_sbindir}/bouncequeue sympa"
sympa-request:	listmaster@$hostname
sympa-owner:	listmaster@$hostname
EOF
  chown sympa.sympa %{_localstatedir}/lib/sympa/aliases

  # mta-specific aliases inclusion procedure
  mta="`readlink /etc/alternatives/sendmail-command 2>/dev/null | cut -d . -f 2`"
  if [ "$mta" == "postfix" ]; then
    database=`/usr/sbin/postconf -h alias_database`
    maps=`/usr/sbin/postconf -h alias_maps`
    postconf -e \
        "alias_database = $database, hash:%{_localstatedir}/lib/sympa/aliases" \
        "alias_maps = $maps, hash:%{_localstatedir}/lib/sympa/aliases"
  else
    cat >> %{_sysconfdir}/aliases <<EOF
:include:	%{_localstatedir}/lib/sympa/aliases
EOF
  fi
  # masqmail don't have this command
  [ -x /usr/bin/newaliases ] && /usr/bin/newaliases
else
  # find aliases file
  aliases=`awk '/sendmail_aliases/ {print $2}' %{_sysconfdir}/sympa/sympa.conf`
  if [ -z "$aliases" ]; then
    aliases=%{_sysconfdir}/aliases
  fi
  # correct pathes
  sed -i \
      -e 's|%{_bindir}/queue|%{_sbindir}/queue|' \
      -e 's|%{_bindir}/bouncequeue|%{_sbindir}/bouncequeue|' \
      $aliases
  # regenerate aliases
  /usr/bin/newaliases
fi

%preun
%_preun_service sympa

if [ $1 = 0 ]; then
  # uninstallation

  # remove aliases
  mta="`readlink /etc/alternatives/sendmail-command 2>/dev/null | cut -d . -f 2`"
  if [ "$mta" == "postfix" ]; then
    database=`/usr/sbin/postconf -h alias_database | \
      sed -e 's|, hash:%{_localstatedir}/lib/sympa/aliases||'`
    maps=`/usr/sbin/postconf -h alias_maps | \
      sed -e 's|, hash:%{_localstatedir}/lib/sympa/aliases||'`
    postconf -e \
      "alias_database = $database" \
      "alias_maps = $maps"
  else
    sed -i -e '/:include:   %{_localstatedir}/lib/sympa/aliases/d' \
      %{_sysconfdir}/aliases
  fi
  /usr/bin/newaliases
fi

%postun
%_postun_userdel sympa

%files -f sympa.lang
%{_docdir}/%{name}
%doc README.update.urpmi

# variable directories
%attr(-,sympa,sympa) %{_localstatedir}/lib/sympa
%attr(-,sympa,sympa) %{_localstatedir}/spool/sympa

# config files
%dir %{_sysconfdir}/sympa
%config(noreplace) %attr(640,root,sympa) %{_sysconfdir}/sympa/sympa.conf

%{_unitdir}/sympa.service
%{_unitdir}/sympa-outgoing.service
%{_unitdir}/sympa-archive.service
%{_unitdir}/sympa-bounce.service
%{_unitdir}/sympa-task.service
%{_prefix}/lib/tmpfiles.d/sympa.conf

# binaries
%attr(-,sympa,sympa) %{_sbindir}/queue
%attr(-,sympa,sympa) %{_sbindir}/bouncequeue
%attr(-,sympa,sympa) %{_sbindir}/familyqueue
%attr(-,sympa,sympa) %{_sbindir}/sympa_newaliases.pl
%attr(-,root,sympa) %{_sbindir}/sympa_newaliases-wrapper
%{_sbindir}/sympa
%{_sbindir}/sympa.pl
%{_sbindir}/sympa_msg.pl
%{_sbindir}/sympa_automatic.pl
%{_sbindir}/alias_manager.pl
%{_sbindir}/archived.pl
%{_sbindir}/bounced.pl
%{_sbindir}/bulk.pl
%{_sbindir}/task_manager.pl

# other
%{_datadir}/sympa
%{_mandir}/man1/*
%{_mandir}/man8/*
%{_mandir}/man5/*

%files www
%dir %{_libdir}/sympa
%dir %{_libdir}/sympa/cgi
%{_libdir}/sympa/cgi/wwsympa.fcgi
%{_libdir}/sympa/cgi/sympa_soap_server.fcgi
%attr(-,sympa,sympa) %{_libdir}/sympa/cgi/sympa_soap_server-wrapper.fcgi
%attr(-,sympa,sympa) %{_libdir}/sympa/cgi/wwsympa-wrapper.fcgi
%config(noreplace) %{_webappconfdir}/sympa.conf

%files mysql
%{_unitdir}/sympa.service.d/mysql.conf

%files postgresql
%{_unitdir}/sympa.service.d/postgresql.conf


%changelog
* Mon Dec 16 2024 bcornec <bcornec> 6.2.74-1.mga10
+ Revision: 2125712
- Update to sympa 6.2.74 and fix CVE-2024-55919

* Thu Feb 29 2024 bcornec <bcornec> 6.2.72-4.mga10
+ Revision: 2045605
- Adds the autoreconf step to build sympa

* Thu Feb 29 2024 bcornec <bcornec> 6.2.72-3.mga10
+ Revision: 2045604
- Adds a README.update.urpmi to document upgrade process for sympa admin

* Mon Feb 19 2024 danf <danf> 6.2.72-2.mga10
+ Revision: 2042568
- use the released, not just tagged, source file
- update the URL

* Fri Sep 22 2023 bcornec <bcornec> 6.2.72-1.mga10
+ Revision: 1989293
- Update to upstream sympa 6.2.72

* Sat Dec 17 2022 guillomovitch <guillomovitch> 6.2.70-1.mga9
+ Revision: 1924308
- new version 6.2.70

* Sat Apr 02 2022 guillomovitch <guillomovitch> 6.2.68-1.mga9
+ Revision: 1841018
- new version 6.2.68

* Mon Mar 28 2022 umeabot <umeabot> 6.2.66-2.mga9
+ Revision: 1830548
- Mageia 9 Mass Rebuild

* Sun Nov 28 2021 guillomovitch <guillomovitch> 6.2.66-1.mga9
+ Revision: 1759732
- new version 6.2.66

* Sun Aug 22 2021 guillomovitch <guillomovitch> 6.2.64-1.mga9
+ Revision: 1742319
- new version 6.2.64

* Tue Jan 05 2021 neoclust <neoclust> 6.2.60-1.mga8
+ Revision: 1668978
- New version 6.2.60

* Fri Oct 23 2020 guillomovitch <guillomovitch> 6.2.58-1.mga8
+ Revision: 1638942
- new version 6.2.58

* Mon Jun 01 2020 guillomovitch <guillomovitch> 6.2.56-1.mga8
+ Revision: 1589452
- new version 6.2.56
- don't ship date_structure.version, this is not a configuration file

* Thu Mar 05 2020 guillomovitch <guillomovitch> 6.2.54-1.mga8
+ Revision: 1554120
- new version 6.2.54

* Tue Feb 18 2020 umeabot <umeabot> 6.2.52-2.mga8
+ Revision: 1541572
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Dec 30 2019 guillomovitch <guillomovitch> 6.2.52-1.mga8
+ Revision: 1474941
- new version 6.2.52

* Wed Oct 02 2019 guillomovitch <guillomovitch> 6.2.48-1.mga8
+ Revision: 1448940
- new version 6.2.48

* Thu Jul 04 2019 guillomovitch <guillomovitch> 6.2.44-1.mga8
+ Revision: 1418628
- new version 6.2.44
- enforce usage of /run instead of /var/run

* Sun Apr 21 2019 tmb <tmb> 6.2.42-1.mga7
+ Revision: 1394488
- update to 6.2.42

* Mon Feb 11 2019 tmb <tmb> 6.2.40-1.mga7
+ Revision: 1365270
- update to 6.2.40

* Sat Oct 20 2018 tmb <tmb> 6.2.36-1.mga7
+ Revision: 1323033
- BR: perl-File-Copy-Recursive
- BR: perl-Unicode-LineBreak
- BR: perl-HTML-Parser
- BR: perl-DBI
- BR: perl-URI
- BR: perl-DateTime
- update to 6.2.36 (CVE-2018-1000671)
- BR: perl-MIME-EncWords

* Sun Sep 23 2018 umeabot <umeabot> 6.2.32-2.mga7
+ Revision: 1301272
- Mageia 7 Mass Rebuild

* Tue Jun 12 2018 tmb <tmb> 6.2.32-1.mga7
+ Revision: 1236492
- update to 6.2.32

* Fri Mar 30 2018 tmb <tmb> 6.2.30-1.mga7
+ Revision: 1213673
- update to 6.2.30

* Mon Feb 26 2018 tmb <tmb> 6.2.24-1.mga7
+ Revision: 1205251
- BR: perl-Class-Singleton
- update to 6.2.24
- update filelists

* Sun Sep 17 2017 guillomovitch <guillomovitch> 6.2.18-1.mga7
+ Revision: 1155091
- new version 6.2.18
- recommends perl-Mail-DKIM for DKIM support
- add sympa-database packages for managing database-specific dependencies and service ordering

* Fri Jun 24 2016 guillomovitch <guillomovitch> 6.2.16-1.mga6
+ Revision: 1037463
- new version 6.2.16

* Thu Jun 23 2016 guillomovitch <guillomovitch> 6.2.15-1.mga6
+ Revision: 1037362
- new version 6.2.15
- use upstream systemd files
- drop obsolete mageia-specific README.urpmi file

* Sun Dec 13 2015 guillomovitch <guillomovitch> 6.2.12-1.mga6
+ Revision: 910238
- new version 6.2.12

* Wed Nov 04 2015 guillomovitch <guillomovitch> 6.2.9-2.mga6
+ Revision: 897791
- fix automatic dependencies

* Wed Oct 21 2015 guillomovitch <guillomovitch> 6.2.9-1.mga6
+ Revision: 893989
- new version 6.2.9

* Tue Feb 17 2015 guillomovitch <guillomovitch> 6.1.24-3.mga5
+ Revision: 815409
- add a soft dependency on FCGI perl module (#15097)

* Sat Jan 31 2015 guillomovitch <guillomovitch> 6.1.24-2.mga5
+ Revision: 812857
- only provide a fallback handler for wwsympa.fcgi if mod_fcgid is not installed, in default apache configuration

* Fri Jan 23 2015 guillomovitch <guillomovitch> 6.1.24-1.mga5
+ Revision: 811961
- new version

* Wed Oct 15 2014 umeabot <umeabot> 6.1.23-3.mga5
+ Revision: 743506
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 6.1.23-2.mga5
+ Revision: 732792
- add exclude

* Fri Sep 26 2014 guillomovitch <guillomovitch> 6.1.23-1.mga5
+ Revision: 724869
- new version 6.1.23
- fix automatic dependencies

* Tue Sep 16 2014 umeabot <umeabot> 6.1.22-2.mga5
+ Revision: 689651
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Fri Jun 13 2014 guillomovitch <guillomovitch> 6.1.22-1.mga5
+ Revision: 636025
- new version 6.1.22
- new version

* Mon Oct 21 2013 luigiwalser <luigiwalser> 6.1.17-3.mga4
+ Revision: 540836
- fix pod2man errors due to non-ascii chars with no encoding set
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
+ guillomovitch <guillomovitch>
- define newaliases arg at build time, to ensure correct alias update

* Wed Feb 06 2013 guillomovitch <guillomovitch> 6.1.17-1.mga3
+ Revision: 394785
- new version

* Mon Jan 14 2013 umeabot <umeabot> 6.1.16-2.mga3
+ Revision: 383886
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Nov 17 2012 guillomovitch <guillomovitch> 6.1.16-1.mga3
+ Revision: 319138
- new version

* Sat Oct 06 2012 guillomovitch <guillomovitch> 6.1.15-1.mga3
+ Revision: 303060
- new version

* Fri Sep 14 2012 guillomovitch <guillomovitch> 6.1.14-1.mga3
+ Revision: 293844
- new version

* Fri Aug 24 2012 guillomovitch <guillomovitch> 6.1.11-5.mga3
+ Revision: 283663
- make webapp configuration file compliant with apache 2.4

* Sat Aug 04 2012 guillomovitch <guillomovitch> 6.1.11-4.mga3
+ Revision: 278467
- fix path in apache configuration file (#6772)

* Tue Jul 10 2012 guillomovitch <guillomovitch> 6.1.11-2.mga3
+ Revision: 269257
- add systemd support
- drop sysinit support
- add soft dependency on perl-CGI-Fast
- update README.urpmi, as db schema files location changed
- mention the need of proper DBD driver package
- new version

* Tue May 08 2012 pterjan <pterjan> 6.1.9-2.mga2
+ Revision: 234918
- Fix initscript's LSB header

* Tue Mar 27 2012 guillomovitch <guillomovitch> 6.1.9-1.mga2
+ Revision: 227182
- new version

* Wed Dec 07 2011 guillomovitch <guillomovitch> 6.1.7-1.mga2
+ Revision: 178321
- new version

* Mon Sep 26 2011 dmorgan <dmorgan> 6.1.5-2.mga2
+ Revision: 147873
- Fix deps in rpm-mageia-setup

* Sun Jun 19 2011 kharec <kharec> 6.1.5-1.mga2
+ Revision: 109677
- new version 6.1.5

* Sun May 15 2011 pterjan <pterjan> 6.1.4-2.mga1
+ Revision: 98970
- Rebuild for fixed find-requires

* Mon Apr 18 2011 misc <misc> 6.1.4-1.mga1
+ Revision: 87648
- remove version check, as all recents versions are ok
- update sympa to 6.1.4

* Sun Mar 06 2011 ennael <ennael> 6.1.3-1.mga1
+ Revision: 65703
- clean spec file
+ kharec <kharec>
- imported package sympa


* Mon Nov 15 2010 Nicolas Lécureuil <nlecureuil@mandriva.com> 6.1.3-1mdv2011.0
+ Revision: 597693
- Update to version 6.1.3

* Mon Oct 25 2010 Guillaume Rousse <guillomovitch@mandriva.org> 6.1.1-1mdv2011.0
+ Revision: 589265
- new version

* Sat Oct 02 2010 Guillaume Rousse <guillomovitch@mandriva.org> 6.1-0.beta7.2mdv2011.0
+ Revision: 582491
- patch0: robot_custome_parameter is not mandatory
- fix www interface configuration

* Wed Sep 29 2010 Guillaume Rousse <guillomovitch@mandriva.org> 6.1-0.beta7.1mdv2011.0
+ Revision: 582059
- new version

* Sat Jul 17 2010 Guillaume Rousse <guillomovitch@mandriva.org> 6.1-0.beta4.1mdv2011.0
+ Revision: 554584
- new version

* Sat May 29 2010 Guillaume Rousse <guillomovitch@mandriva.org> 6.0.2-1mdv2010.1
+ Revision: 546579
- new version (bugfix release)
- rework init script to make it more robust
- patch1: fix bulk daemon
- patch2: fix created directories ownership
- no need to explicitely add a group, %%_pre_useradd does it already
- split web interface in www subpackage, and use apache-independant dependencies (fix #59174)
- drop smrsh support, let expert sendmails users manage it themselves (fix #59173)
- don't run newalias if it doesn't exists (bug #59172)

  + Michael Scherer <misc@mandriva.org>
    - fix missing group issue, fix issue #59172

* Tue Apr 27 2010 Guillaume Rousse <guillomovitch@mandriva.org> 6.0.1-6mdv2010.1
+ Revision: 539525
- don't forget bulk module in init script

* Fri Apr 23 2010 Guillaume Rousse <guillomovitch@mandriva.org> 6.0.1-5mdv2010.1
+ Revision: 538361
- fix aliases on update, as queue and bouncequeue are now installed under %%{_sbindir}

* Sat Jan 23 2010 Guillaume Rousse <guillomovitch@mandriva.org> 6.0.1-4mdv2010.1
+ Revision: 495353
- no need for specific logrotate configuration anymore
- use standard 'mail' syslog facility, instead of a specific one, for sake of simplicity

* Tue Jan 19 2010 Guillaume Rousse <guillomovitch@mandriva.org> 6.0.1-3mdv2010.1
+ Revision: 493849
- rely on filetrigger for reloading apache configuration begining with 2010.1, rpm-helper macros otherwise
- switch to open to all by default, as the application does not allow modification of system state
- use installation patch submitted upstream

* Sat Jan 02 2010 Guillaume Rousse <guillomovitch@mandriva.org> 6.0.1-1mdv2010.1
+ Revision: 485176
- new version
- switch apache default access policy to open by default, as the application does not allow local modifications
- fix automatic dependencies

* Fri Dec 04 2009 Guillaume Rousse <guillomovitch@mandriva.org> 6.0-1mdv2010.1
+ Revision: 473475
- enforce new default access policy
- update to 6.0 final

* Fri Oct 09 2009 Oden Eriksson <oeriksson@mandriva.com> 6.0-0.b2.3mdv2010.0
+ Revision: 456333
- don't hardcode the buildhost host name at install

* Wed Sep 09 2009 Guillaume Rousse <guillomovitch@mandriva.org> 6.0-0.b2.2mdv2010.0
+ Revision: 434775
- fix dependencies

* Sun Aug 30 2009 Guillaume Rousse <guillomovitch@mandriva.org> 6.0-0.b2.1mdv2010.0
+ Revision: 422521
- new version
- spec cleanup, now than sympa installation process has been fixed upstream

* Sun Feb 15 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.4.6-1mdv2009.1
+ Revision: 340593
- new release

* Sun Jul 06 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.4.3-1mdv2009.0
+ Revision: 232181
- new version
- sync init script with mailman one
- use a single url prefix for all web stuff
- new version
- update install patch
- install cgi files under /var/www/sympa
- mysql dependency in init scrip

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Mon Feb 18 2008 Thierry Vignaud <tv@mandriva.org> 5.3.4-2mdv2008.1
+ Revision: 171135
- rebuild
- fix "foobar is blabla" summary (=> "blabla") so that it looks nice in rpmdrake

* Wed Feb 06 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.3.4-1mdv2008.1
+ Revision: 163224
- new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Sep 06 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.3.3-1mdv2008.0
+ Revision: 80909
- use new syslog rpm-helper
- new version

* Thu Jun 07 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.3.1-1mdv2008.0
+ Revision: 36757
- new version
  fix monharc dependency capitalization

* Sun Jun 03 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.3-1mdv2008.0
+ Revision: 34888
- final version

* Sun Jun 03 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.3-0.beta4.2mdv2008.0
+ Revision: 34884
- new mandriva specific FHS-compliant init script

* Wed May 30 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.3-0.beta4.1mdv2008.0
+ Revision: 32945
- new version


* Thu Mar 08 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.3-0.beta1.2mdv2007.1
+ Revision: 134999
- don't remove aliases file on removal, just remove it from system aliases configuration, as mailman

* Wed Mar 07 2007 Guillaume Rousse <guillomovitch@mandriva.org> 5.3-0.beta1.1mdv2007.1
+ Revision: 134290
- use alias_database and alias_maps directives for postfix, so as to make newaliases command functionnal
- use get_free_syslog_facility helper script
- new version, using standard pre-release versionning scheme
- main configuration file is supposed to contains a password
- uses a patch instead of in-spec substitutions to handle installation, so as to fix insane perms also
- install wrappers setuid root

* Wed Nov 15 2006 Guillaume Rousse <guillomovitch@mandriva.org> 5.3a.10-1mdv2007.1
+ Revision: 84462
- attempt to migrate aliases automatically during upgrade
  use alias_database insteaf of alias_maps for postfix, as it allow to use sendmail-compatible newaliases command
- remove aliase database also on uninstallation
- fix listmaster adress substitution
- all sympa-created static web content is now created in %%_localstatedir/sympa/www
  change Apache alias from wws to sympa, for consistency with other webapps
- no need to create log file, syslog will do it alone
- fix syslog modification in %%preun
- fix alias removal during %%preun
- sanitize permissions
- sanitize setup a little bit:
- executables are in system standard directories (%%_bindir and %%_sbindir)
- samples are in documentation
- scripts are not samples
- sanitize macro use
- new version
- use a distinct alias file in /var/lib/sympa, and make sure it is included by MTA
- ship all documentation
- fix openssl path
- fix %%post
- LDAP support is optional
- move runtime-independant configuration change from %%post to %%install
- yet more cleanup
- ready-to-use static css directory
- fix %%post scriptlet
- put static web content (icons) into their own directory
- put messages files in correct place
- no need to add apache in sympa group, wwsympa is setuid
- useless verbosity
- don't install wrapper, wwsympa is setuid
- sanitize automatic configuration a little bit:
- dont use NIS domain name at all
- use hostname rather than domain name, as it is a safer default
- chain regexpes
- better regexp coherency
- correctly setup log facility in sympa configuration
- drop commented lines
- use herein document for README.urpmi
  more explicit instructions
- don't mess with mysql database creating script, as it breaks it
- use new webapps macros, allowing to discard versioned apache dependencies
  no need to requires mails-server during %%pre
- Import sympa

* Mon Jun 05 2006 Anne Nicolas <anicolas@mandriva.com> 5.2.1-1mdk
- new version, bug fix

* Wed May 17 2006 Anne Nicolas <anicolas@mandriva.com> 5.2-2mdk
- fix sympa.conf configuration for hostname

* Fri Apr 21 2006 Anne Nicolas <anicolas@mandriva.com> 5.2-1mdk
- update of translations
- performances optimization
- full virtual hosting support

* Sun Feb 05 2006 Anne Nicolas <anicolas@mandriva.com> 5.1.2-1mdk
- new version, bug fix

* Thu Sep 01 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 5.1.0-2mdk
- buildrequires: perl-libintl-perl (Locale/Messages.pm)

* Sun Aug 28 2005 Anne Nicolas <anicolas@mandrakesoft.com> 5.1.0-1mdk
- new version
- add perl-Template require
- modify configure adding --with-docdir
- modify Makefile searching

* Thu Jul 14 2005 Guillaume Rousse <guillomovitch@mandriva.org> 4.1.5-2mdk 
- new mail-server requires
- new apache setup
- new apache macros
- use herein documents instead of additional sources
- ship sendmail secure shell link instead of managing it through post-installation procedure
- spec cleanup
- use %%mkrel

* Sat Feb 26 2005 Anne Nicolas <anicolas@mandrakesoft.com> 4.1.5-1mdk
- new version

* Fri Feb 18 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 4.1.4-2mdk
- spec file cleanups, remove the ADVX-build stuff
- strip away annoying ^M

* Thu Feb 10 2005 Anne Nicolas <anne@mandrakesoft.com> 4.1.4-1mdk
- new version because of bug in web interface

* Tue Feb 08 2005 Anne Nicolas <anne@mandrakesoft.com> 4.1.3-1mdk
- new version (last one for this branch)

* Mon Nov 01 2004 Michael Scherer <misc@mandrake.org> 4.1.2-5mdk
- Buildrequires perl-MailTools

* Sat Oct 23 2004 Anne Nicolas <anne@mandrake.org> 4.1.2-4mdk
- use README.urpmi feature (thanks to rgs and misc)

* Sat Oct 23 2004 Anne Nicolas <anne@mandrake.org> 4.1.2-3mdk
- fix bug in mysql database creation script
- add comment about database creation at the end of install

* Thu Aug 05 2004 Anne Nicolas <anne@mandrake.org> 4.1.2-2mdk
- create sympa directory in /var/log for sympa's logs
- modify syslog : log all priorities in /var/log/sympa/sympa.log

* Thu Jul 08 2004 Anne Nicolas <anne@mandrake.org> 4.1.2-1mdk
- add apache configuration for wws
- remove patch for init file
- new version

* Sat Apr 24 2004 Anne Nicolas <anne@mandrake.org> 4.1.1-3mdk
- add SympaTransport exception
- add require perl-MailTools

* Fri Apr 23 2004 Olivier Blin <blino@mandrake.org> 4.1.1-2mdk
- merge changelog from the real 3.4.4.3-4mdk release to let the package be uploaded again (after a three months break)

* Thu Apr 22 2004 Guillaume Rousse <guillomovitch@mandrake.org> 4.1.1-1mdk
- new version, by popular demand (you know who you are)
- no more explicit perl dependencies, let spec-helper do its job

* Thu Apr 08 2004 Guillaume Rousse <guillomovitch@mandrake.org> 3.4.4.3-5mdk
- fixed multiple groups handling when adding sympa to apache group (Francis Muguet <muguet@ensta.fr>)
- requires mod_fastcgi and install cgi in correct dir (Guillaume Sauvenay <sauvenay@ccr.jussieu.fr>)
- user rpm-helper facility to create empty files

